##################################
### SearchPage.tcl             ###
### Version 1.2                ###
### By Wcc                     ###
### wcc@techmonkeys.org        ###
### http://www.dawgtcl.com:81/ ###
### EFnet #|DAWG|Tcl           ###
##################################

############################################################################
### Copyright  2000 - 2002 |DAWG| Scripting Group. All rights reserved. ###
############################################################################

################################################################
## This script searches a web page for text, and tells you if ##
## the string was found on the page.  NOTE: The bot may pause ##
## briefly during a search.                                   ##
################################################################

##############
## COMMANDS ##
##################################################################
## PUB ## !searchpage <url> *<search string>* (Can be changed.) ##
######### Searches the given url for a string of text.          ##
##################################################################
## DCC ## .searchpage <url> *<search string>* (Can be changed.) ##
######### Searches the given url for a string of text.          ##
##################################################################

##########################################################
## Just load the script, edit the settings, and rehash. ##
##########################################################

#################################################
# Set the flag required to use the script here. #
#################################################

set searchpage_setting(flag) "-|-"

##################################################
# Set the dcc command for using the script here. #
##################################################

set searchpage_setting(dcc_cmd) "searchpage"

##################################################
# Set the pub command for using the script here. #
##################################################

set searchpage_setting(pub_cmd) "!searchpage"

###################################
# Enable use of bold in DCC chat? #
###################################

set searchpage_setting(bold) 1

##############################################
# Prefix "SEARCHPAGE:" in DCC chat messages? #
##############################################

set searchpage_setting(SEARCHPAGE:) 1

####################
# Code begins here #
####################

if {![string match 1.6.* $version]} { putlog "\002SEARCHPAGE:\002 \002WARNING:\002 This script is intended to run on eggdrop 1.6.x or later." }
if {[info tclversion] < 8.2} { putlog "\002SEARCHPAGE:\002 \002WARNING:\002 This script is intended to run on Tcl Version 8.2 or later." }

package require http
bind pub $searchpage_setting(flag) $searchpage_setting(pub_cmd) searchpage_pub
bind dcc $searchpage_setting(flag) $searchpage_setting(dcc_cmd) searchpage_dcc

proc searchpage_dopre {} {
	global searchpage_setting
	if {!$searchpage_setting(SEARCHPAGE:)} { return "" }
	if {!$searchpage_setting(bold)} { return "SEARCHPAGE: " }
	return "\002SEARCHPAGE:\002 "
}
proc searchpage_pub {nick uhost hand chan text} {
	global searchpage_setting
	if {[lindex [split $text] 1] == ""} { putserv "PRIVMSG $chan :Usage: $searchpage_setting(pub_cmd) <url> <search string>" ; return }
	searchpage_go 1 $chan [join [lindex [split $text] 0]] [join [lrange [split $text] 1 end]]
}
proc searchpage_dcc {hand idx text} {
	global searchpage_setting
	if {[lindex [split $text] 1] == ""} { putdcc $idx "[split_dopre]Usage: $searchpage_setting(dcc_cmd) <url> <search string>" ; return }
	searchpage_go 0 $idx [join [lindex [split $text] 0]] [join [lrange [split $text] 1 end]]
}
proc searchpage_go {type ic url string} {
	::http::config -useragent "SearchPage.tcl"
	if {[catch {set tok [::http::geturl $url]} error]} {
		set text "An error occured while connecting to $url."
		if {$type} { putserv "PRIVMSG $ic :$text" } { putdcc $ic "[searchpage_dopre]$text" }
		return
	}
	if {[::http::ncode $tok] != 200} {
		set text "An error occured while connecting to $url."
		if {$type} { putserv "PRIVMSG $ic :$text" } { putdcc $ic "[searchpage_dopre]$text" }
		::http::cleanup $tok ; return
	}
	set data [searchpage_html2text [::http::data $tok]]
	set text "$string was [expr {([string match [string tolower $string] [string tolower $data]])?"found":"not found"}] on $url."
	if {$type} { putserv "PRIVMSG $ic :$text" } { putdcc $ic "[searchpage_dopre]$text" }
	::http::cleanup $tok ; return
}
proc searchpage_html2text {text} {
	regsub -all {<.*?>}  $text {}    text
	regsub -all {&nbsp;} $text { }   text
	regsub -all {&lt;}   $text {<}   text
	regsub -all {&gt;}   $text {>}   text
	regsub -all {&quot;} $text {\\"} text
	regsub -all {&#39;}  $text {'}   text
	regsub -all {&#91;}  $text {\\[} text
	regsub -all {&#93;}  $text {\\]} text
	regsub -all {&copy;} $text {}   text
	regsub -all {&amp;}  $text {&}   text
	return $text
}
putlog "\002SEARCHPAGE:\002 SearchPage.tcl Version 1.2 by Wcc is loaded."
